@@ -1,6 +1,6 @@
 package Map::Tube::Delhi::Line::Yellow;
 
-$Map::Tube::Delhi::Line::Yellow::VERSION   = '0.27';
+$Map::Tube::Delhi::Line::Yellow::VERSION   = '0.28';
 $Map::Tube::Delhi::Line::Yellow::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::Delhi::Line::Yellow - Delhi Metro Yellow Line stations.
 
 =head1 VERSION
 
-Version 0.27
+Version 0.28
 
 =head1 DESCRIPTION
 
@@ -73,6 +73,22 @@ Delhi Metro Yellow Line stations.
 
 =back
 
+=head1 MAP
+
+Delhi Metro Map: L<Yellow Line|https://raw.githubusercontent.com/Manwar/Map-Tube-Delhi/master/maps/Yellow.png>
+map generated by plugin L<Map::Tube::Plugin::Graph>.
+
+=begin html
+
+<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-Delhi/master/maps/Yellow.png">
+<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-Delhi/master/maps/Yellow.png"
+     alt    = "Delhi Metro Map: Yellow Line"
+     width  = "500px"
+     height = "500px"/>
+</a>
+
+=end html
+
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
